@@ -1,4 +1,5 @@
-# Copyright (C) 2002-2025 Free Software Foundation, Inc.
+# Copyright (C) 2002, 2004, 2006, 2008, 2010 Free Software Foundation,
+# Inc.
 
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -11,12 +12,12 @@
 # GNU General Public License for more details.
 
 # You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <https://www.gnu.org/licenses/>.
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-##################################################################
-# The master copy of this file is in Automake's source repository.
-# Please send updates to automake-patches@gnu.org.
-##################################################################
+###############################################################
+# The main copy of this file is in Automake's CVS repository. #
+# Updates should be sent to automake-patches@gnu.org.         #
+###############################################################
 
 package Autom4te::Channels;
 
@@ -35,7 +36,7 @@ Autom4te::Channels - support functions for error and warning management
   register_channel 'system', type => 'error', exit_code => 4;
 
   # Output a message on channel 'unused'.
-  msg 'unused', "$file:$line", "unused variable '$var'";
+  msg 'unused', "$file:$line", "unused variable `$var'";
 
   # Make the 'unused' channel silent.
   setup_channel 'unused', silent => 1;
@@ -66,24 +67,26 @@ etc.) that can also be overridden on a per-message basis.
 
 =cut
 
-use 5.006; use strict; use warnings;
-use Carp;
+use 5.005;
+use strict;
 use Exporter;
+use Carp;
 use File::Basename;
 
-our @ISA = qw (Exporter);
-our @EXPORT = qw ($exit_code $warnings_are_errors
-		  &reset_local_duplicates &reset_global_duplicates
-		  &register_channel &msg &exists_channel &channel_type
-		  &setup_channel &setup_channel_type
-		  &dup_channel_setup &drop_channel_setup
-		  &buffer_messages &flush_messages
-		  &setup_channel_queue &pop_channel_queue
-		  US_GLOBAL US_LOCAL
-		  UP_NONE UP_TEXT UP_LOC_TEXT);
+use vars qw (@ISA @EXPORT %channels $me);
 
-our %channels;
-our $me = basename $0;
+@ISA = qw (Exporter);
+@EXPORT = qw ($exit_code $warnings_are_errors
+	      &reset_local_duplicates &reset_global_duplicates
+	      &register_channel &msg &exists_channel &channel_type
+	      &setup_channel &setup_channel_type
+	      &dup_channel_setup &drop_channel_setup
+	      &buffer_messages &flush_messages
+	      &setup_channel_queue &pop_channel_queue
+	      US_GLOBAL US_LOCAL
+	      UP_NONE UP_TEXT UP_LOC_TEXT);
+
+$me = basename $0;
 
 =head2 Global Variables
 
@@ -96,7 +99,8 @@ the C<exit_code> options of C<fatal> and C<error> channels.
 
 =cut
 
-our $exit_code = 0;
+use vars qw ($exit_code);
+$exit_code = 0;
 
 =item C<$warnings_are_errors>
 
@@ -105,7 +109,8 @@ errors (i.e. if they should update C<$exit_code>).
 
 =cut
 
-our $warnings_are_errors = 0;
+use vars qw ($warnings_are_errors);
+$warnings_are_errors = 0;
 
 =back
 
@@ -255,8 +260,11 @@ be ignored.
 
 =cut
 
+use vars qw (%_default_options %_global_duplicate_messages
+	     %_local_duplicate_messages);
+
 # Default options for a channel.
-our %_default_options =
+%_default_options =
   (
    type => 'warning',
    exit_code => 1,
@@ -276,14 +284,14 @@ our %_default_options =
 # Filled with output messages as keys, to detect duplicates.
 # The value associated with each key is the number of occurrences
 # filtered out.
-our %_local_duplicate_messages = ();
-our %_global_duplicate_messages = ();
+%_local_duplicate_messages = ();
+%_global_duplicate_messages = ();
 
 sub _reset_duplicates (\%)
 {
   my ($ref) = @_;
   my $dup = 0;
-  foreach my $k (keys %$ref) # sort keys not needed
+  foreach my $k (keys %$ref)
     {
       $dup += $ref->{$k};
     }
@@ -325,7 +333,7 @@ sub _merge_options (\%%)
   my ($hash, %options) = @_;
   local $_;
 
-  foreach (sort keys %options)
+  foreach (keys %options)
     {
       if (exists $hash->{$_})
 	{
@@ -333,7 +341,7 @@ sub _merge_options (\%%)
 	}
       else
 	{
-	  confess "unknown option '$_'";
+	  confess "unknown option `$_'";
 	}
     }
   if ($hash->{'ordered'})
@@ -396,7 +404,8 @@ sub _format_sub_message ($$)
 }
 
 # Store partial messages here. (See the 'partial' option.)
-our $partial = '';
+use vars qw ($partial);
+$partial = '';
 
 # _format_message ($LOCATION, $MESSAGE, %OPTIONS)
 # -----------------------------------------------
@@ -577,12 +586,12 @@ associated to the message.
 For instance to complain about some unused variable C<mumble>
 declared at line 10 in F<foo.c>, one could do:
 
-  msg 'unused', 'foo.c:10', "unused variable 'mumble'";
+  msg 'unused', 'foo.c:10', "unused variable `mumble'";
 
 If channel C<unused> is not silent (and if this message is not a duplicate),
 the following would be output:
 
-  foo.c:10: unused variable 'mumble'
+  foo.c:10: unused variable `mumble'
 
 C<$location> can also be an instance of C<Autom4te::Location>.  In this
 case, the stack of contexts will be displayed in addition.
@@ -611,9 +620,11 @@ both print
 =cut
 
 
+use vars qw (@backlog %buffering);
+
 # See buffer_messages() and flush_messages() below.
-our %buffering = ();	# The map of channel types to buffer.
-our @backlog = ();		# The buffer of messages.
+%buffering = ();	# The map of channel types to buffer.
+@backlog = ();		# The buffer of messages.
 
 sub msg ($$;$%)
 {
@@ -625,13 +636,7 @@ sub msg ($$;$%)
       $location = '';
     }
 
-  if (!exists $channels{$channel})
-    {
-      # This can happen as a result of e.g. m4_warn([nonsense], [message])
-      # so it should not crash.
-      report_bad_channel($channel, $location);
-      $channel = 'syntax';
-    }
+  confess "unknown channel $channel" unless exists $channels{$channel};
 
   my %opts = %{$channels{$channel}};
   _merge_options (%opts, %options);
@@ -665,45 +670,6 @@ sub msg ($$;$%)
     }
 }
 
-sub report_bad_channel ($$)
-{
-  my ($channel, $location) = @_;
-  my $message;
-  my $report_as = 'error';
-
-  # quotemeta is both too aggressive (e.g. it escapes '-') and
-  # too generous (it turns control characters into \ + themselves,
-  # not into symbolic escapes).
-  my $q_channel = $channel;
-  $q_channel =~ s/(?=[\"\$\'\@\`\\])/\\/g;
-  $q_channel =~ s/([^\x20-\x7e])/sprintf('\\x%02X', ord $1)/eg;
-  $q_channel = '"' . $q_channel . '"';
-
-  if ($channel eq '' || $channel eq 'all')
-    {
-      # Prior to version 2.70, the Autoconf manual said it was valid to use
-      # "all" and the empty string as the category argument to m4_warn, so
-      # don't treat those cases as errors.
-      $report_as = 'obsolete';
-      $message = "use of $q_channel as a diagnostic category is obsolete\n";
-      $message .= "(see automake --help for a list of valid categories)";
-    }
-  elsif ($channel eq 'none'
-         || ($channel =~ /^no-/ && exists $channels{substr($channel, 3)}))
-    {
-      # Also recognize "none" and "no-[category]", as someone might have
-      # thought anything acceptable to -W is also acceptable to m4_warn.
-      # Note: m4_warn([error], [...]) does actually issue an error.
-      $message = "-W accepts $q_channel, but it is not a diagnostic category";
-    }
-  else
-    {
-      $message = "unknown diagnostic category " . $q_channel;
-    }
-
-  msg $report_as, $location, $message;
-}
-
 
 =item C<setup_channel ($channel, %options)>
 
@@ -728,7 +694,7 @@ with those specified by C<%options>.
 sub setup_channel_type ($%)
 {
   my ($type, %opts) = @_;
-  foreach my $channel (sort keys %channels)
+  foreach my $channel (keys %channels)
     {
       setup_channel $channel, %opts
 	if $channels{$channel}{'type'} eq $type;
@@ -750,13 +716,14 @@ entry, while C<drop_channel_setup ()> just deletes it.
 
 =cut
 
-our @_saved_channels = ();
-our @_saved_werrors = ();
+use vars qw (@_saved_channels @_saved_werrors);
+@_saved_channels = ();
+@_saved_werrors = ();
 
 sub dup_channel_setup ()
 {
   my %channels_copy;
-  foreach my $k1 (keys %channels) # sort keys not needed
+  foreach my $k1 (keys %channels)
     {
       $channels_copy{$k1} = {%{$channels{$k1}}};
     }
@@ -820,7 +787,7 @@ and the key to use for serialization.
 sub setup_channel_queue ($$)
 {
   my ($queue, $key) = @_;
-  foreach my $channel (sort keys %channels)
+  foreach my $channel (keys %channels)
     {
       setup_channel $channel, queue => $queue, queue_key => $key
         if $channels{$channel}{'ordered'};
@@ -851,3 +818,20 @@ Written by Alexandre Duret-Lutz E<lt>F<adl@gnu.org>E<gt>.
 =cut
 
 1;
+
+### Setup "GNU" style for perl-mode and cperl-mode.
+## Local Variables:
+## perl-indent-level: 2
+## perl-continued-statement-offset: 2
+## perl-continued-brace-offset: 0
+## perl-brace-offset: 0
+## perl-brace-imaginary-offset: 0
+## perl-label-offset: -2
+## cperl-indent-level: 2
+## cperl-brace-offset: 0
+## cperl-continued-brace-offset: 0
+## cperl-label-offset: -2
+## cperl-extra-newline-before-brace: t
+## cperl-merge-trailing-else: nil
+## cperl-continued-statement-offset: 2
+## End:
