@@ -1,4 +1,4 @@
-# Copyright (C) 2003-2025 Free Software Foundation, Inc.
+# Copyright (C) 2003-2012 Free Software Foundation, Inc.
 
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -11,24 +11,24 @@
 # GNU General Public License for more details.
 
 # You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <https://www.gnu.org/licenses/>.
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-##################################################################
-# The master copy of this file is in Automake's source repository.
-# Please send updates to automake-patches@gnu.org.
-##################################################################
+###############################################################
+# The main copy of this file is in Automake's git repository. #
+# Updates should be sent to automake-patches@gnu.org.         #
+###############################################################
 
 package Autom4te::Configure_ac;
 
-use 5.006; use strict; use warnings;
-
+use strict;
 use Exporter;
-
-use Autom4te::ChannelDefs;
 use Autom4te::Channels;
+use Autom4te::ChannelDefs;
 
-our @ISA = qw (Exporter);
-our @EXPORT = qw (&find_configure_ac &require_configure_ac);
+use vars qw (@ISA @EXPORT);
+
+@ISA = qw (Exporter);
+@EXPORT = qw (&find_configure_ac &require_configure_ac);
 
 =head1 NAME
 
@@ -74,21 +74,19 @@ sub find_configure_ac (;@)
   my $configure_in =
     File::Spec->canonpath (File::Spec->catfile ($directory, 'configure.in'));
 
-  if (-f $configure_in)
+  if (-f $configure_ac)
     {
-      msg ('obsolete', "autoconf input should be named 'configure.ac'," .
-                       " not 'configure.in'");
-      if (-f $configure_ac)
+      if (-f $configure_in)
 	{
 	  msg ('unsupported',
 	       "'$configure_ac' and '$configure_in' both present.\n"
 	       . "proceeding with '$configure_ac'");
-          return $configure_ac
 	}
-      else
-        {
-          return $configure_in;
-        }
+      return $configure_ac
+    }
+  elsif (-f $configure_in)
+    {
+      return $configure_in;
     }
   return $configure_ac;
 }
@@ -103,8 +101,26 @@ Like C<find_configure_ac>, but fail if neither is present.
 sub require_configure_ac (;$)
 {
   my $res = find_configure_ac (@_);
-  fatal "'configure.ac' is required" unless -f $res;
+  fatal "'configure.ac' or 'configure.in' is required"
+    unless -f $res;
   return $res
 }
 
 1;
+
+### Setup "GNU" style for perl-mode and cperl-mode.
+## Local Variables:
+## perl-indent-level: 2
+## perl-continued-statement-offset: 2
+## perl-continued-brace-offset: 0
+## perl-brace-offset: 0
+## perl-brace-imaginary-offset: 0
+## perl-label-offset: -2
+## cperl-indent-level: 2
+## cperl-brace-offset: 0
+## cperl-continued-brace-offset: 0
+## cperl-label-offset: -2
+## cperl-extra-newline-before-brace: t
+## cperl-merge-trailing-else: nil
+## cperl-continued-statement-offset: 2
+## End:
